@@ -35,11 +35,13 @@ if TYPE_CHECKING:
 
 class MsSqlToHiveOperator(BaseOperator):
     """
-    Moves data from Microsoft SQL Server to Hive. The operator runs
-    your query against Microsoft SQL Server, stores the file locally
-    before loading it into a Hive table. If the ``create`` or
-    ``recreate`` arguments are set to ``True``,
-    a ``CREATE TABLE`` and ``DROP TABLE`` statements are generated.
+    Moves data from Microsoft SQL Server to Hive.
+
+    The operator runs your query against Microsoft SQL Server, stores
+    the file locally before loading it into a Hive table. If the
+    ``create`` or ``recreate`` arguments are set to ``True``, a
+    ``CREATE TABLE`` and ``DROP TABLE`` statements are generated.
+
     Hive data types are inferred from the cursor's metadata.
     Note that the table generated in Hive uses ``STORED AS textfile``
     which isn't the most efficient serialization format. If a
