@@ -33,10 +33,11 @@ if TYPE_CHECKING:
 
 class VerticaToHiveOperator(BaseOperator):
     """
-    Moves data from Vertica to Hive. The operator runs
-    your query against Vertica, stores the file locally
-    before loading it into a Hive table. If the ``create`` or
-    ``recreate`` arguments are set to ``True``,
+    Moves data from Vertica to Hive.
+
+    The operator runs your query against Vertica, stores the file
+    locally before loading it into a Hive table. If the ``create``
+    or ``recreate`` arguments are set to ``True``,
     a ``CREATE TABLE`` and ``DROP TABLE`` statements are generated.
     Hive data types are inferred from the cursor's metadata.
     Note that the table generated in Hive uses ``STORED AS textfile``
